==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/ht.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Jere mozaik Gallary Paramèt");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "jere Galeri");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Tout-gwosè Imaj Lajè");
define('MANAGE_GALLERY_FULL_HEIGHT', "Tout-gwosè Imaj Tay");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatura Lajè Imaj");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Imaj Tay");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Prezève Thumb Aspè Pwopòsyon");
define('MANAGE_GALLERY_SHOW_TITLES', "Montre Tit");
define('MANAGE_GALLERY_DISABLE_SORT', "Enfim Sòt");
define('MANAGE_GALLERY_DELETE_IMAGE', "Debarase m de Imaj");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sòt Lòd");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klike sou &#39;Mizajou&#39; yo pibliye <br /> imaj Uploaded ou yo.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tout imaj yo te rdimansyone ak anviwònman yo te sove.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Te gen yon erè rèsizin imaj yo oswa ekonomize anviwònman.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "te imaj ou (yo) te Uploaded.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Te gen yon erè uploading imaj ou (yo).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Dosye a ou yo ap eseye Upload se pa yon imaj.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Dosye a ou yo ap eseye Upload se twò gwo.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "te tit la te sove.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Èske ou sèten ou vle efase imaj");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "te Imaj la efase.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Te gen yon erè efase imaj la.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Ekonomize paramèt ak rèsizin imaj, tanpri, tann ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, tanpri, tann ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Lòd la sòt pa te sove. ou vle sove lòd la sòt?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "te Lòd la imaj sòt te sove.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Te gen yon erè ekonomize sòt nan imaj.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ht.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Jere mozaik Gallary Paramèt");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "jere Galeri");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Tout-gwosè Imaj Lajè");
define('MANAGE_GALLERY_FULL_HEIGHT', "Tout-gwosè Imaj Tay");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatura Lajè Imaj");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Imaj Tay");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Prezève Thumb Aspè Pwopòsyon");
define('MANAGE_GALLERY_SHOW_TITLES', "Montre Tit");
define('MANAGE_GALLERY_DISABLE_SORT', "Enfim Sòt");
define('MANAGE_GALLERY_DELETE_IMAGE', "Debarase m de Imaj");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sòt Lòd");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klike sou &#39;Mizajou&#39; yo pibliye <br /> imaj Uploaded ou yo.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tout imaj yo te rdimansyone ak anviwònman yo te sove.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Te gen yon erè rèsizin imaj yo oswa ekonomize anviwònman.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "te imaj ou (yo) te Uploaded.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Te gen yon erè uploading imaj ou (yo).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Dosye a ou yo ap eseye Upload se pa yon imaj.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Dosye a ou yo ap eseye Upload se twò gwo.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "te tit la te sove.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Èske ou sèten ou vle efase imaj");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "te Imaj la efase.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Te gen yon erè efase imaj la.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Ekonomize paramèt ak rèsizin imaj, tanpri, tann ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, tanpri, tann ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Lòd la sòt pa te sove. ou vle sove lòd la sòt?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "te Lòd la imaj sòt te sove.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Te gen yon erè ekonomize sòt nan imaj.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Dosye ou ap eseye téléchargement pi gwo pase &#39;upload_max_filesize&#39; ou &#39;post_max_size&#39; PHP paramètres. Kontakte administratè sistèm ou an pou ogmante limit sa yo.");
?>
